pub struct AttrFlags(/* private fields */);Implementations
Sourceimpl AttrFlags
impl AttrFlags
Sourcepub const EXCLUDE_USER: Self
pub const EXCLUDE_USER: Self
don’t count user
Sourcepub const EXCLUDE_KERNEL: Self
pub const EXCLUDE_KERNEL: Self
don’t count kernel
Sourcepub const EXCLUDE_HV: Self
pub const EXCLUDE_HV: Self
don’t count hypervisor
Sourcepub const EXCLUDE_IDLE: Self
pub const EXCLUDE_IDLE: Self
don’t count when idle
Sourcepub const INHERIT_STAT: Self
pub const INHERIT_STAT: Self
per task counts
Sourcepub const ENABLE_ON_EXEC: Self
pub const ENABLE_ON_EXEC: Self
next exec enables
Sourcepub const PRECISE_IP_BIT_15: Self
pub const PRECISE_IP_BIT_15: Self
one of the two PRECISE_IP bitmask bits
Sourcepub const PRECISE_IP_BIT_16: Self
pub const PRECISE_IP_BIT_16: Self
one of the two PRECISE_IP bitmask bits
Sourcepub const PRECISE_IP_BITMASK: Self
pub const PRECISE_IP_BITMASK: Self
the full PRECISE_IP bitmask
Sourcepub const SAMPLE_ID_ALL: Self
pub const SAMPLE_ID_ALL: Self
sample_type all events
Sourcepub const EXCLUDE_HOST: Self
pub const EXCLUDE_HOST: Self
don’t count in host
Sourcepub const EXCLUDE_GUEST: Self
pub const EXCLUDE_GUEST: Self
don’t count in guest
Sourcepub const EXCLUDE_CALLCHAIN_KERNEL: Self
pub const EXCLUDE_CALLCHAIN_KERNEL: Self
exclude kernel callchains
Sourcepub const EXCLUDE_CALLCHAIN_USER: Self
pub const EXCLUDE_CALLCHAIN_USER: Self
exclude user callchains
Sourcepub const USE_CLOCKID: Self
pub const USE_CLOCKID: Self
use @clockid for time fields
Sourcepub const CONTEXT_SWITCH: Self
pub const CONTEXT_SWITCH: Self
context switch data
Sourcepub const WRITE_BACKWARD: Self
pub const WRITE_BACKWARD: Self
Write ring buffer from end to beginning
Sourcepub const NAMESPACES: Self
pub const NAMESPACES: Self
include namespaces data
Sourcepub const AUX_OUTPUT: Self
pub const AUX_OUTPUT: Self
generate AUX records instead of events
Sourcepub const INHERIT_THREAD: Self
pub const INHERIT_THREAD: Self
children only inherit if cloned with CLONE_THREAD
Sourcepub const REMOVE_ON_EXEC: Self
pub const REMOVE_ON_EXEC: Self
event is removed from task on exec
Sourceimpl AttrFlags
impl AttrFlags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AttrFlags
impl AttrFlags
Sourcepub const fn iter(&self) -> Iter<AttrFlags>
pub const fn iter(&self) -> Iter<AttrFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AttrFlags>
pub const fn iter_names(&self) -> IterNames<AttrFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl AttrFlags
impl AttrFlags
Sourcepub fn ip_skid_constraint(&self) -> IpSkidConstraint
pub fn ip_skid_constraint(&self) -> IpSkidConstraint
Extract the IpSkidConstraint from the bits.